@@ -1,7 +1,7 @@
 import esphome.codegen as cg
 import esphome.config_validation as cv
 from esphome.components import binary_sensor
-from esphome.const import CONF_DIRECTION, CONF_DEVICE_CLASS, DEVICE_CLASS_MOVING
+from esphome.const import CONF_DIRECTION, DEVICE_CLASS_MOVING
 from . import APDS9960, CONF_APDS9960_ID
 
 DEPENDENCIES = ["apds9960"]
@@ -13,19 +13,18 @@ DIRECTIONS = {
     "RIGHT": "set_right_direction",
 }
 
-CONFIG_SCHEMA = binary_sensor.BINARY_SENSOR_SCHEMA.extend(
+CONFIG_SCHEMA = binary_sensor.binary_sensor_schema(
+    device_class=DEVICE_CLASS_MOVING
+).extend(
     {
-        cv.Required(CONF_DIRECTION): cv.one_of(*DIRECTIONS, upper=True),
         cv.GenerateID(CONF_APDS9960_ID): cv.use_id(APDS9960),
-        cv.Optional(
-            CONF_DEVICE_CLASS, default=DEVICE_CLASS_MOVING
-        ): binary_sensor.device_class,
+        cv.Required(CONF_DIRECTION): cv.one_of(*DIRECTIONS, upper=True),
     }
 )
 
 
-def to_code(config):
-    hub = yield cg.get_variable(config[CONF_APDS9960_ID])
-    var = yield binary_sensor.new_binary_sensor(config)
+async def to_code(config):
+    hub = await cg.get_variable(config[CONF_APDS9960_ID])
+    var = await binary_sensor.new_binary_sensor(config)
     func = getattr(hub, DIRECTIONS[config[CONF_DIRECTION]])
     cg.add(func(var))
