@@ -85,9 +85,7 @@ bool HOT IRAM_ATTR ESPOneWire::read_bit() {
   // whereas on esp-idf it already happens during the pin_mode(OUTPUT)
   // manually correct for this with these constants.
 
-#ifdef USE_ESP32_FRAMEWORK_ARDUINO
-  uint32_t timing_constant = 14;
-#elif defined(USE_ESP32_FRAMEWORK_ESP_IDF)
+#ifdef USE_ESP32
   uint32_t timing_constant = 12;
 #else
   uint32_t timing_constant = 14;
