@@ -38,6 +38,9 @@ void MDNSComponent::compile_records_() {
 #endif
 #ifdef USE_ESP32
     platform = "ESP32";
+#endif
+#ifdef USE_RP2040
+    platform = "RP2040";
 #endif
     if (platform != nullptr) {
       service.txt_records.push_back({"platform", platform});
@@ -45,6 +48,12 @@ void MDNSComponent::compile_records_() {
 
     service.txt_records.push_back({"board", ESPHOME_BOARD});
 
+#if defined(USE_WIFI)
+    service.txt_records.push_back({"network", "wifi"});
+#elif defined(USE_ETHERNET)
+    service.txt_records.push_back({"network", "ethernet"});
+#endif
+
 #ifdef ESPHOME_PROJECT_NAME
     service.txt_records.push_back({"project_name", ESPHOME_PROJECT_NAME});
     service.txt_records.push_back({"project_version", ESPHOME_PROJECT_VERSION});
