@@ -2,13 +2,13 @@
 
 #include "esphome/core/component.h"
 #include "esphome/components/sensor/sensor.h"
-#include "esphome/components/i2c/i2c.h"
+#include "esphome/components/sensirion_common/i2c_sensirion.h"
 
 namespace esphome {
 namespace scd30 {
 
 /// This class implements support for the Sensirion scd30 i2c GAS (VOC and CO2eq) sensors.
-class SCD30Component : public PollingComponent, public i2c::I2CDevice {
+class SCD30Component : public Component, public sensirion_common::SensirionI2CDevice {
  public:
   void set_co2_sensor(sensor::Sensor *co2) { co2_sensor_ = co2; }
   void set_humidity_sensor(sensor::Sensor *humidity) { humidity_sensor_ = humidity; }
@@ -19,17 +19,15 @@ class SCD30Component : public PollingComponent, public i2c::I2CDevice {
     ambient_pressure_compensation_ = (uint16_t)(pressure * 1000);
   }
   void set_temperature_offset(float offset) { temperature_offset_ = offset; }
+  void set_update_interval(uint16_t interval) { update_interval_ = interval; }
 
   void setup() override;
-  void update() override;
+  void update();
   void dump_config() override;
   float get_setup_priority() const override { return setup_priority::DATA; }
 
  protected:
-  bool write_command_(uint16_t command);
-  bool write_command_(uint16_t command, uint16_t data);
-  bool read_data_(uint16_t *data, uint8_t len);
-  uint8_t sht_crc_(uint8_t data1, uint8_t data2);
+  bool is_data_ready_();
 
   enum ErrorCode {
     COMMUNICATION_FAILED,
@@ -41,6 +39,7 @@ class SCD30Component : public PollingComponent, public i2c::I2CDevice {
   uint16_t altitude_compensation_{0xFFFF};
   uint16_t ambient_pressure_compensation_{0x0000};
   float temperature_offset_{0.0};
+  uint16_t update_interval_{0xFFFF};
 
   sensor::Sensor *co2_sensor_{nullptr};
   sensor::Sensor *humidity_sensor_{nullptr};
