@@ -1,57 +1,88 @@
 #pragma once
 
+#include "esphome/core/log.h"
 #include "esphome/core/component.h"
+#include "esphome/core/entity_base.h"
 #include "esphome/core/helpers.h"
 #include "esphome/components/sensor/filter.h"
 
+#include <vector>
+
 namespace esphome {
 namespace sensor {
 
 #define LOG_SENSOR(prefix, type, obj) \
-  if (obj != nullptr) { \
-    ESP_LOGCONFIG(TAG, "%s%s '%s'", prefix, type, obj->get_name().c_str()); \
-    ESP_LOGCONFIG(TAG, "%s  Unit of Measurement: '%s'", prefix, obj->get_unit_of_measurement().c_str()); \
-    ESP_LOGCONFIG(TAG, "%s  Accuracy Decimals: %d", prefix, obj->get_accuracy_decimals()); \
-    if (!obj->get_icon().empty()) { \
-      ESP_LOGCONFIG(TAG, "%s  Icon: '%s'", prefix, obj->get_icon().c_str()); \
+  if ((obj) != nullptr) { \
+    ESP_LOGCONFIG(TAG, "%s%s '%s'", prefix, LOG_STR_LITERAL(type), (obj)->get_name().c_str()); \
+    if (!(obj)->get_device_class().empty()) { \
+      ESP_LOGCONFIG(TAG, "%s  Device Class: '%s'", prefix, (obj)->get_device_class().c_str()); \
     } \
-    if (!obj->unique_id().empty()) { \
-      ESP_LOGV(TAG, "%s  Unique ID: '%s'", prefix, obj->unique_id().c_str()); \
+    ESP_LOGCONFIG(TAG, "%s  State Class: '%s'", prefix, state_class_to_string((obj)->get_state_class()).c_str()); \
+    ESP_LOGCONFIG(TAG, "%s  Unit of Measurement: '%s'", prefix, (obj)->get_unit_of_measurement().c_str()); \
+    ESP_LOGCONFIG(TAG, "%s  Accuracy Decimals: %d", prefix, (obj)->get_accuracy_decimals()); \
+    if (!(obj)->get_icon().empty()) { \
+      ESP_LOGCONFIG(TAG, "%s  Icon: '%s'", prefix, (obj)->get_icon().c_str()); \
     } \
-    if (obj->get_force_update()) { \
+    if (!(obj)->unique_id().empty()) { \
+      ESP_LOGV(TAG, "%s  Unique ID: '%s'", prefix, (obj)->unique_id().c_str()); \
+    } \
+    if ((obj)->get_force_update()) { \
       ESP_LOGV(TAG, "%s  Force Update: YES", prefix); \
     } \
   }
 
+/**
+ * Sensor state classes
+ */
+enum StateClass : uint8_t {
+  STATE_CLASS_NONE = 0,
+  STATE_CLASS_MEASUREMENT = 1,
+  STATE_CLASS_TOTAL_INCREASING = 2,
+  STATE_CLASS_TOTAL = 3,
+};
+
+std::string state_class_to_string(StateClass state_class);
+
 /** Base-class for all sensors.
  *
  * A sensor has unit of measurement and can use publish_state to send out a new value with the specified accuracy.
  */
-class Sensor : public Nameable {
+class Sensor : public EntityBase {
  public:
   explicit Sensor();
   explicit Sensor(const std::string &name);
 
-  /** Manually set the unit of measurement of this sensor. By default the sensor's default defined by
-   * unit_of_measurement() is used.
-   *
-   * @param unit_of_measurement The unit of measurement, "" to disable.
-   */
+  /// Get the unit of measurement, using the manual override if set.
+  std::string get_unit_of_measurement();
+  /// Manually set the unit of measurement.
   void set_unit_of_measurement(const std::string &unit_of_measurement);
 
-  /** Manually set the icon of this sensor. By default the sensor's default defined by icon() is used.
-   *
-   * @param icon The icon, for example "mdi:flash". "" to disable.
-   */
-  void set_icon(const std::string &icon);
-
-  /** Manually set the accuracy in decimals for this sensor. By default, the sensor's default defined by
-   * accuracy_decimals() is used.
-   *
-   * @param accuracy_decimals The accuracy decimal that should be used.
-   */
+  /// Get the accuracy in decimals, using the manual override if set.
+  int8_t get_accuracy_decimals();
+  /// Manually set the accuracy in decimals.
   void set_accuracy_decimals(int8_t accuracy_decimals);
 
+  /// Get the device class, using the manual override if set.
+  std::string get_device_class();
+  /// Manually set the device class.
+  void set_device_class(const std::string &device_class);
+
+  /// Get the state class, using the manual override if set.
+  StateClass get_state_class();
+  /// Manually set the state class.
+  void set_state_class(StateClass state_class);
+
+  /**
+   * Get whether force update mode is enabled.
+   *
+   * If the sensor is in force_update mode, the frontend is required to save all
+   * state changes to the database when they are published, even if the state is the
+   * same as before.
+   */
+  bool get_force_update() const { return force_update_; }
+  /// Set force update mode.
+  void set_force_update(bool force_update) { force_update_ = force_update; }
+
   /// Add a filter to the filter chain. Will be appended to the back.
   void add_filter(Filter *filter);
 
@@ -73,24 +104,11 @@ class Sensor : public Nameable {
   /// Clear the entire filter chain.
   void clear_filters();
 
-  /// Getter-syntax for .value. Please use .state instead.
-  float get_value() const ESPDEPRECATED(".value is deprecated, please use .state");
   /// Getter-syntax for .state.
   float get_state() const;
-  /// Getter-syntax for .raw_value. Please use .raw_state instead.
-  float get_raw_value() const ESPDEPRECATED(".raw_value is deprecated, please use .raw_state");
   /// Getter-syntax for .raw_state
   float get_raw_state() const;
 
-  /// Get the accuracy in decimals. Uses the manual override if specified or the default value instead.
-  int8_t get_accuracy_decimals();
-
-  /// Get the unit of measurement. Uses the manual override if specified or the default value instead.
-  std::string get_unit_of_measurement();
-
-  /// Get the Home Assistant Icon. Uses the manual override if specified or the default value instead.
-  std::string get_icon();
-
   /** Publish a new state to the front-end.
    *
    * First, the new state will be assigned to the raw_value. Then it's passed through all filters
@@ -100,12 +118,6 @@ class Sensor : public Nameable {
    */
   void publish_state(float state);
 
-  /** Push a new value to the MQTT front-end.
-   *
-   * Note: deprecated, please use publish_state.
-   */
-  void push_new_value(float state) ESPDEPRECATED("push_new_value is deprecated. Please use .publish_state instead");
-
   // ========== INTERNAL METHODS ==========
   // (In most use cases you won't need these)
   /// Add a callback that will be called every time a filtered value arrives.
@@ -122,8 +134,9 @@ class Sensor : public Nameable {
    */
   float state;
 
-  /** This member variable stores the current raw state of the sensor. Unlike .state,
-   * this will be updated immediately when publish_state is called.
+  /** This member variable stores the current raw state of the sensor, without any filters applied.
+   *
+   * Unlike .state,this will be updated immediately when publish_state is called.
    */
   float raw_state;
 
@@ -137,63 +150,44 @@ class Sensor : public Nameable {
    */
   virtual std::string unique_id();
 
-  /// Return with which interval the sensor is polled. Return 0 for non-polling mode.
-  virtual uint32_t update_interval();
-
-  /// Calculate the expected update interval for values that pass through all filters.
-  uint32_t calculate_expected_filter_update_interval();
-
   void internal_send_state_to_frontend(float state);
 
-  bool get_force_update() const { return force_update_; }
-  /** Set this sensor's force_update mode.
-   *
-   * If the sensor is in force_update mode, the frontend is required to save all
-   * state changes to the database when they are published, even if the state is the
-   * same as before.
-   */
-  void set_force_update(bool force_update) { force_update_ = force_update; }
-
  protected:
-  /** Override this to set the Home Assistant unit of measurement for this sensor.
+  /** Override this to set the default unit of measurement.
    *
-   * Return "" to disable this feature.
-   *
-   * @return The icon of this sensor, for example "°C".
+   * @deprecated This method is deprecated, set the property during config validation instead. (2022.1)
    */
   virtual std::string unit_of_measurement();  // NOLINT
 
-  /** Override this to set the Home Assistant icon for this sensor.
+  /** Override this to set the default accuracy in decimals.
    *
-   * Return "" to disable this feature.
-   *
-   * @return The icon of this sensor, for example "mdi:battery".
+   * @deprecated This method is deprecated, set the property during config validation instead. (2022.1)
    */
-  virtual std::string icon();  // NOLINT
-
-  /// Return the accuracy in decimals for this sensor.
   virtual int8_t accuracy_decimals();  // NOLINT
 
-  uint32_t hash_base() override;
+  /** Override this to set the default device class.
+   *
+   * @deprecated This method is deprecated, set the property during config validation instead. (2022.1)
+   */
+  virtual std::string device_class();  // NOLINT
+
+  /** Override this to set the default state class.
+   *
+   * @deprecated This method is deprecated, set the property during config validation instead. (2022.1)
+   */
+  virtual StateClass state_class();  // NOLINT
 
   CallbackManager<void(float)> raw_callback_;  ///< Storage for raw state callbacks.
   CallbackManager<void(float)> callback_;      ///< Storage for filtered state callbacks.
-  /// Override the unit of measurement
-  optional<std::string> unit_of_measurement_;
-  /// Override the icon advertised to Home Assistant, otherwise sensor's icon will be used.
-  optional<std::string> icon_;
-  /// Override the accuracy in decimals, otherwise the sensor's values will be used.
-  optional<int8_t> accuracy_decimals_;
-  Filter *filter_list_{nullptr};  ///< Store all active filters.
+
   bool has_state_{false};
-  bool force_update_{false};
-};
+  Filter *filter_list_{nullptr};  ///< Store all active filters.
 
-class PollingSensorComponent : public PollingComponent, public Sensor {
- public:
-  explicit PollingSensorComponent(const std::string &name, uint32_t update_interval);
-
-  uint32_t update_interval() override;
+  optional<std::string> unit_of_measurement_;           ///< Unit of measurement override
+  optional<int8_t> accuracy_decimals_;                  ///< Accuracy in decimals override
+  optional<std::string> device_class_;                  ///< Device class override
+  optional<StateClass> state_class_{STATE_CLASS_NONE};  ///< State class override
+  bool force_update_{false};                            ///< Force update mode
 };
 
 }  // namespace sensor
