@@ -769,7 +769,7 @@ void Sprinkler::resume() {
     ESP_LOGD(TAG, "Resuming valve %u with %u seconds remaining", this->paused_valve_.value_or(0),
              this->resume_duration_.value_or(0));
     this->fsm_request_(this->paused_valve_.value(), this->resume_duration_.value());
-    this->reset_resume_();
+    this->reset_resume();
   } else {
     ESP_LOGD(TAG, "No valve to resume!");
   }
@@ -783,6 +783,11 @@ void Sprinkler::resume_or_start_full_cycle() {
   }
 }
 
+void Sprinkler::reset_resume() {
+  this->paused_valve_.reset();
+  this->resume_duration_.reset();
+}
+
 const char *Sprinkler::valve_name(const size_t valve_number) {
   if (this->is_a_valid_valve(valve_number)) {
     return this->valve_[valve_number].controller_switch->get_name().c_str();
@@ -1101,11 +1106,6 @@ void Sprinkler::reset_cycle_states_() {
   }
 }
 
-void Sprinkler::reset_resume_() {
-  this->paused_valve_.reset();
-  this->resume_duration_.reset();
-}
-
 void Sprinkler::fsm_request_(size_t requested_valve, uint32_t requested_run_duration) {
   this->next_req_.set_valve(requested_valve);
   this->next_req_.set_run_duration(requested_run_duration);
