@@ -1,4 +1,5 @@
 import logging
+import multiprocessing
 import os
 import re
 
@@ -11,10 +12,12 @@ from esphome.const import (
     CONF_BOARD_FLASH_MODE,
     CONF_BUILD_PATH,
     CONF_COMMENT,
+    CONF_COMPILE_PROCESS_LIMIT,
     CONF_ESPHOME,
     CONF_FRAMEWORK,
     CONF_INCLUDES,
     CONF_LIBRARIES,
+    CONF_MIN_VERSION,
     CONF_NAME,
     CONF_ON_BOOT,
     CONF_ON_LOOP,
@@ -30,6 +33,7 @@ from esphome.const import (
     KEY_CORE,
     TARGET_PLATFORMS,
     PLATFORM_ESP8266,
+    __version__ as ESPHOME_VERSION,
 )
 from esphome.core import CORE, coroutine_with_priority
 from esphome.helpers import copy_file_if_changed, walk_files
@@ -96,6 +100,25 @@ def valid_project_name(value: str):
     return value
 
 
+def validate_version(value: str):
+    min_version = cv.Version.parse(value)
+    current_version = cv.Version.parse(ESPHOME_VERSION)
+    if current_version < min_version:
+        raise cv.Invalid(
+            f"Your ESPHome version is too old. Please update to at least {min_version}"
+        )
+    return value
+
+
+if "ESPHOME_DEFAULT_COMPILE_PROCESS_LIMIT" in os.environ:
+    _compile_process_limit_default = min(
+        int(os.environ["ESPHOME_DEFAULT_COMPILE_PROCESS_LIMIT"]),
+        multiprocessing.cpu_count(),
+    )
+else:
+    _compile_process_limit_default = cv.UNDEFINED
+
+
 CONF_ESP8266_RESTORE_FROM_FLASH = "esp8266_restore_from_flash"
 CONFIG_SCHEMA = cv.All(
     cv.Schema(
@@ -136,6 +159,12 @@ CONFIG_SCHEMA = cv.All(
                     cv.Required(CONF_VERSION): cv.string_strict,
                 }
             ),
+            cv.Optional(CONF_MIN_VERSION, default=ESPHOME_VERSION): cv.All(
+                cv.version_number, validate_version
+            ),
+            cv.Optional(
+                CONF_COMPILE_PROCESS_LIMIT, default=_compile_process_limit_default
+            ): cv.int_range(min=1, max=multiprocessing.cpu_count()),
         }
     ),
     validate_hostname,
@@ -179,7 +208,11 @@ def preload_core_config(config, result):
     ]
 
     if not has_oldstyle and not newstyle_found:
-        raise cv.Invalid("Platform missing for core options!", [CONF_ESPHOME])
+        raise cv.Invalid(
+            "Platform missing. You must include one of the available platform keys: "
+            + ", ".join(TARGET_PLATFORMS),
+            [CONF_ESPHOME],
+        )
     if has_oldstyle and newstyle_found:
         raise cv.Invalid(
             f"Please remove the `platform` key from the [esphome] block. You're already using the new style with the [{conf[CONF_PLATFORM]}] block",
