@@ -32,6 +32,7 @@
 #define USE_MEDIA_PLAYER
 #define USE_MQTT
 #define USE_NUMBER
+#define USE_OTA
 #define USE_OTA_PASSWORD
 #define USE_OTA_STATE_CALLBACK
 #define USE_POWER_SUPPLY
@@ -67,18 +68,18 @@
 #define USE_ESP32_BLE_CLIENT
 #define USE_ESP32_BLE_SERVER
 #define USE_ESP32_CAMERA
-#define USE_ESP32_IGNORE_EFUSE_MAC_CRC
 #define USE_IMPROV
 #define USE_SOCKET_IMPL_BSD_SOCKETS
+#define USE_WIFI_11KV_SUPPORT
 #define USE_BLUETOOTH_PROXY
 
 #ifdef USE_ARDUINO
-#define USE_ARDUINO_VERSION_CODE VERSION_CODE(1, 0, 6)
+#define USE_ARDUINO_VERSION_CODE VERSION_CODE(2, 0, 5)
 #define USE_ETHERNET
 #endif
 
 #ifdef USE_ESP_IDF
-#define USE_ARDUINO_VERSION_CODE VERSION_CODE(4, 3, 0)
+#define USE_ESP_IDF_VERSION_CODE VERSION_CODE(4, 4, 2)
 #endif
 #endif
 
@@ -89,15 +90,16 @@
 #define USE_ESP8266_PREFERENCES_FLASH
 #define USE_HTTP_REQUEST_ESP8266_HTTPS
 #define USE_SOCKET_IMPL_LWIP_TCP
-#endif
-
-// Disabled feature flags
-//#define USE_BSEC  // Requires a library with proprietary license.
-
-#define USE_DASHBOARD_IMPORT
 
 // Dummy firmware payload for shelly_dimmer
 #define USE_SHD_FIRMWARE_MAJOR_VERSION 56
 #define USE_SHD_FIRMWARE_MINOR_VERSION 5
 #define USE_SHD_FIRMWARE_DATA \
   {}
+
+#endif
+
+// Disabled feature flags
+//#define USE_BSEC  // Requires a library with proprietary license.
+
+#define USE_DASHBOARD_IMPORT
